pub struct MetadataToml {
pub package_name: String,
pub name: String,
pub panel_version: VersionReq,
}Fields
package_name: Stringname: Stringpanel_version: VersionReqImplementations
Sourceimpl MetadataToml
impl MetadataToml
Sourcepub fn get_package_identifier(&self) -> String
pub fn get_package_identifier(&self) -> String
Get the package identifier for this extension.
This is derived from the package name by replacing . with _.
Example: com.example.myextension becomes com_example_myextension.
Sourcepub fn convert_package_name_to_identifier(package_name: &str) -> String
pub fn convert_package_name_to_identifier(package_name: &str) -> String
Convert a package name to an identifier by replacing . with _.
Example: com.example.myextension becomes com_example_myextension.
Sourcepub fn is_valid_package_identifier(identifier: &str) -> bool
pub fn is_valid_package_identifier(identifier: &str) -> bool
Validate that a package identifier matches the same constraints as the package name
validation in ExtensionDistrFile::validate, but with _ instead of . as the separator.
Sourcepub fn convert_identifier_to_package_name(identifier: &str) -> String
pub fn convert_identifier_to_package_name(identifier: &str) -> String
Convert an identifier to a package name by replacing _ with ..
Example: com_example_myextension becomes com.example.myextension.